#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    Setup file for ConfigUpdater.

    This file was generated with PyScaffold 3.0.3.
    PyScaffold helps you to put up the scaffold of your new Python project.
    Learn more under: http://pyscaffold.org/
"""

from setuptools import setup

if __name__ == "__main__":
    setup(use_pyscaffold=True)
